@@ -5,14 +5,14 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 //
 
-#ifndef INCLUDED_UHD_TRANSPORT_ZERO_COPY_HPP
-#define INCLUDED_UHD_TRANSPORT_ZERO_COPY_HPP
+#pragma once
 
 #include <uhd/config.hpp>
+#include <uhd/utils/noncopyable.hpp>
 #include <boost/detail/atomic_count.hpp>
 #include <boost/intrusive_ptr.hpp>
-#include <boost/shared_ptr.hpp>
 #include <boost/utility.hpp>
+#include <memory>
 
 namespace uhd { namespace transport {
 
@@ -20,14 +20,7 @@ namespace uhd { namespace transport {
 class UHD_API managed_buffer
 {
 public:
-    managed_buffer(void) : _ref_count(0), _buffer(NULL), _length(0)
-    {
-#ifdef UHD_TXRX_DEBUG_PRINTS
-        _mb_num = s_buffer_count;
-        // From Boost website: atomic_count seems only to have precrement operator.
-        ++s_buffer_count;
-#endif
-    }
+    managed_buffer(void) : _ref_count(0), _buffer(NULL), _length(0) {}
 
     virtual ~managed_buffer(void) {}
 
@@ -51,7 +44,8 @@ public:
      * Get a pointer to the underlying buffer.
      * \return a pointer into memory
      */
-    template <class T> UHD_INLINE T cast(void) const
+    template <class T>
+    UHD_INLINE T cast(void) const
     {
         return static_cast<T>(_buffer);
     }
@@ -82,24 +76,11 @@ public:
         return (int)_ref_count;
     }
 
-#ifdef UHD_TXRX_DEBUG_PRINTS
-    int num() const
-    {
-        return _mb_num;
-    }
-#endif
-
 protected:
     void* _buffer;
     size_t _length;
-#ifdef UHD_TXRX_DEBUG_PRINTS
-    int _mb_num;
-#endif
 
 private:
-#ifdef UHD_TXRX_DEBUG_PRINTS
-    static boost::detail::atomic_count s_buffer_count;
-#endif
 };
 
 UHD_INLINE void intrusive_ptr_add_ref(managed_buffer* p)
@@ -162,10 +143,10 @@ struct zero_copy_xport_params
  * Provides a way to get send and receive buffers
  * with memory managed by the transport object.
  */
-class UHD_API zero_copy_if : boost::noncopyable
+class UHD_API zero_copy_if : uhd::noncopyable
 {
 public:
-    typedef boost::shared_ptr<zero_copy_if> sptr;
+    typedef std::shared_ptr<zero_copy_if> sptr;
 
     /*!
      * Clean up tasks before releasing the transport object.
@@ -216,5 +197,3 @@ public:
 };
 
 }} // namespace uhd::transport
-
-#endif /* INCLUDED_UHD_TRANSPORT_ZERO_COPY_HPP */
